==> nextcloud-20.0.8p0.tgz: nextcloud/apps/support/l10n/pt_BR.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Link:",
    "Password:" : "Senha:",
    "Generating system report failed." : "Falha ao gerar o relatório de sistema",
    "Subscription notifications" : "Notificações de assinatura",
    "Could not create folder \"System information\" to store generated report." : "Não foi possível criar a pasta \"System information\" para armazenar o relatório gerado.",
    "Could not create file \"%s\" to store generated report." : "Não foi possível criar o arquivo \"%s\" para armazenar o relatório gerado.",
    "Could not share file \"%s\"." : "Não foi possível compartilhar o arquivo \"%s\".",
    "Nextcloud Subscription" : "Assinatura Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Seu servidor não tem uma Assinatura Nextcloud ou ela expirou.",
    "Your Nextcloud server subscription does not cover your number of users." : "Seu assinatura Nextcloud não cobre seu número de usuários.",
    "Your Nextcloud Subscription has expired!" : "Sua Assinatura Nextcloud expirou!",
    "Your server has no Nextcloud Subscription" : "Seu servidor não tem Assinatura Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Seu servidor Nextcloud não é apoiado por uma Assinatura Corporativa do Nextcloud.",
    "A Nextcloud Enterprise Subscription means the original developers behind your self-hosted cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Uma Assinatura do Nextcloud Empresarial significa que os desenvolvedores originais por trás do seu servidor estarão 100% dedicados ao seu sucesso: a segurança, escalabilidade, desempenho e funcionalidade do seu serviço!",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Se a configuração do servidor for interrompida e os funcionários pararem, você não precisará depender de fóruns online para encontrar uma solução. Você tem acesso direto aos nossos experientes engenheiros!",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Você tem um contrato com o fornecedor enviando informações de segurança, atenuações, correções e atualizações antecipadas.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Se você precisar ficar mais tempo na sua versão atual sem interrupções, não precisará rodar o software sem as atualizações de segurança.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Você tem a melhor experiência disponível para lidar com problemas de desempenho e escalabilidade.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Você tem acesso à documentação e experiência corretas para responder rapidamente as questões de conformidade ou cumprir GDPR, HIPAA e outros requisitos de regulamentação.",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication an other features only available in a limited form for free or develop further integrations and capabilities to your needs." : "Também podemos integrar com Outlook, Office Online, comunicação integrada de áudio e vídeo escalável e bate-papo e outros recursos disponíveis de forma limitada para integrações e recursos gratuitos ou adicionais às suas necessidades.",
    "A subscription helps you get the most out of Nextcloud!" : "Uma assinatura ajuda você a aproveitar ao máximo o Nextcloud!",
    "Learn more now" : "Saiba mais agora",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Este e-mail foi enviado a todos os administradores pelo aplicativo de suporte em seu Nextcloud em %1$s porque você tem mais que %2$s usuários registrados.",
    "Your Nextcloud server Subscription is over limit" : "Sua Assinatura do servidor Nextcloud está acima do limite",
    "Dear admin," : "Prezado admin,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "Sua Assinatura Nextcloud não cobre o número de usuários atualmente ativos neste servidor. Entre em contato com seu gerente de conta do Nextcloud para atualizar sua assinatura!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s é o seu gerente de conta e pode ser acessado por e-mail via %2$s ou telefone via %3$s.",
    "Thank you," : "Obrigado,",
    "Your Nextcloud team" : "Sua equipe Nextcloud",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "Este e-mail foi enviado a todos os administradores pelo aplicativo de suporte do Nextcloud em  %s porque você tem mais usuários do que sua assinatura cobre.",
    "Your Nextcloud server Subscription is expired" : "Sua assinatura Nextcloud expirou",
    "Your Nextcloud server Subscription is expired!" : "Sua assinatura Nextcloud expirou!",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "Sua Assinatura Nextcloud expirou! Entre em contato com seu gerente de conta do Nextcloud para atualizá-la!",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Este e-mail foi enviado a todos os administradores pelo aplicativo de suporte em seu Nextcloud em %s porque sua assinatura expirou.",
    "Support" : "Suporte",
    "Getting support and help for your Nextcloud" : "Obtendo suporte e ajuda para o seu Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "O aplicativo de suporte fornece acesso direto a recursos de ajuda e consultoria, contato dedicado com seu gerente de conta e uma visão geral da sua assinatura corporativa.",
    "Basic subscription" : "Assinatura Básica",
    "Standard subscription" : "Assinatura Padrão",
    "Premium subscription" : "Assinatura Premium",
    "Géant subscription" : "Assinatura Gigante",
    "Silver partner subscription" : "Assinatura de parceiro Prata",
    "Gold partner subscription" : "Assinatura de parceiro Ouro",
    "Subscription" : "Assinatura",
    "Over subscription limit" : "Limite da assinatura",
    "Valid subscription" : "Assinatura válida",
    "Expired subscription" : "Assinatura expirada",
    "Subscription key:" : "Chave de assinatura:",
    "_Expires in %n year_::_Expires in %n years_" : ["Expira em %n ano","Expira em %n anos"],
    "_Expires in %n month_::_Expires in %n months_" : ["Expira em %n mês","Expira em %n meses"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Expira em %n semana","Expira em %n semanas"],
    "_Expires in %n day_::_Expires in %n days_" : ["Expira em %n dia","Expira em %n dias"],
    "For an unlimited amount of users" : "Para uma quantidade ilimitada de usuários",
    "_For %n active users_::_For %n active users_" : ["Para %n usuário ativo","Para %n usuários ativos"],
    "_For %n users_::_For %n users_" : ["Para %n usuário","Para %n usuários"],
    "_currently at %n user_::_currently at %n users_" : ["atualmente com %n usuário","atualmente com %n usuários"],
    "Includes support for %s" : "Inclui suporte para %s",
    "Includes support for %1$s & %2$s" : "Inclui suporte para %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Inclui suporte para %1$s, %2$s & %3$s",
    "Update subscription key" : "Atualizar chave de assinatura",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s é o seu gerente de conta. Não hesite em entrar em contato conosco se tiver dúvidas sobre sua assinatura.",
    "You can find answers to common question in our portal and also file support requests there." : "Você pode encontrar respostas para perguntas frequentes em nosso portal e também solicitações de suporte.",
    "Access Nextcloud portal" : "Acessar o portal Nextcloud",
    "System information" : "Informação do sistema",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Obtenha informações do sistema para o suporte. O botão abaixo gera um arquivo de texto na pasta \"Informações do sistema\" e o compartilha como um link público protegido por senha. O link é válido por 2 semanas.",
    "Generate system report" : "Gerar relatório do sistema",
    "Enterprise subscription recommended" : "Assinatura corporativa recomendada",
    "No active enterprise subscription" : "Nenhuma assinatura corporativa ativa",
    "Unsupported" : "Não suportado",
    "This Nextcloud server has no Enterprise Subscription." : "Este servidor não tem uma Assinatura Corporativa.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Uma Assinatura Corporativa tira o máximo do Nextcloud, mantém seus dados seguros e o servidor funcionará de maneira confiável o tempo todo.",
    "Advantages" : "Vantagens",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Acesso ao conhecimento técnico dos desenvolvedores do Nextcloud por meio de documentação e suporte",
    "Access to additional capabilities like Outlook integration, online office and more" : "Acesso a recursos adicionais como integração com o Outlook, office online e muito mais",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Acesso a conhecimento em escalabilidade e capacidades para Arquivos e Conversas",
    "Optional branding, consulting, architecture advice" : "Branding opcional, consultoria e aconselhamento de arquitetura",
    "Confidential security notification service, mitigations, patches and advice" : "Serviço de notificação de segurança confidencial, atenuação de problemas, patches e conselhos",
    "Compliance certification, advice and documentation" : "Certificação de conformidade, aconselhamento e documentação",
    "Get a quote" : "Peça um orçamento",
    "More information" : "Mais informações",
    "Subscription benefits" : "Benefícios da assinatura",
    "Pricing" : "Preço",
    "Commmunity support" : "Suporte da comunidade",
    "Forum" : "Fórum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud é um software livre que é suportado por uma comunidade muito ativa. Por favor, registre-se no fórum para perguntas e conversas com outras pessoas.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "O Nextcloud usa o GitHub como plataforma de trabalho colaborativo. Você pode enviar relatórios de erros diretamente lá.",
    "Chat" : "Bate-papo",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Converse conosco no canal IRC #nextcloud no Freenode.",
    "Nextcloud forum" : "Fórum Nextcloud",
    "Nextcloud at GitHub" : "Nextcloud no GitHub",
    "Open chat" : "Abrir bate-papo",
    "Subscription key" : "Chave de assinatura",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Se você tiver uma Assinatura Nextcloud ativa, insira a chave de assinatura aqui.",
    "Learn more about an enterprise subscription." : "Saiba mais sobre assinatura corporativa.",
    "Set subscription key" : "Definir uma chave de assinatura",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "A informação da assinatura não pôde ser obtida no momento. Uma nova tentativa foi agendada, volte mais tarde.",
    "The subscription key was invalid." : "A chave de assinatura é inválida.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Não foi possível verificar a chave de assinatura porque esse servidor não tem conexão à internet. Entre em contato com a equipe de suporte para resolver isso.",
    "The subscription key had an invalid format." : "A chave de assinatura tem um formato inválido.",
    "While fetching the subscription information an error happened." : "Ocorreu um erro ao buscar as informações da assinatura.",
    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "O botão abaixo gera um arquivo de texto na pasta \"Informações do sistema\" e o compartilha como um link público protegido por senha. O link é válido por duas semanas.",
    "News" : "Notícias",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Para informações atualizadas sobre o Nextcloud, inscreva-se no boletim informativo e siga-nos na redes sociais.",
    "Like our Facebook page" : "Curta nossa página no Facebook",
    "Follow us on Twitter" : "Siga-nos no Twitter",
    "Check out our blog" : "Verifique nosso blog",
    "Subscribe to our newsletter" : "Assine nosso boletim informativo"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-23.0.8.tgz: nextcloud/apps/support/l10n/pt_BR.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Link:",
    "Password:" : "Senha:",
    "Generating system report failed." : "Falha ao gerar o relatório de sistema",
    "Could not create folder \"System information\" to store generated report." : "Não foi possível criar a pasta \"System information\" para armazenar o relatório gerado.",
    "Could not create file \"%s\" to store generated report." : "Não foi possível criar o arquivo \"%s\" para armazenar o relatório gerado.",
    "Could not share file \"%s\". Nevertheless, you can find it in the folder \"System information\"." : "Não foi possível compartilhar o arquivo \"%s\". Apesar disso, ele pode ser encontrado na pasta \"System information\".",
    "Subscription notifications" : "Notificações de assinatura",
    "Nextcloud Subscription" : "Assinatura Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Seu servidor não tem uma Assinatura Nextcloud ou ela expirou.",
    "Your Nextcloud server subscription does not cover your number of users." : "Seu assinatura Nextcloud não cobre seu número de usuários.",
    "Your Nextcloud Subscription has expired!" : "Sua Assinatura Nextcloud expirou!",
    "Your server has no Nextcloud Subscription" : "Seu servidor não tem Assinatura Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Seu servidor Nextcloud não é apoiado por uma Assinatura Corporativa do Nextcloud.",
    "A Nextcloud Enterprise Subscription means the original developers behind your self-hosted cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Uma Assinatura do Nextcloud Empresarial significa que os desenvolvedores originais por trás do seu servidor estarão 100% dedicados ao seu sucesso: a segurança, escalabilidade, desempenho e funcionalidade do seu serviço!",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Se a configuração do servidor for interrompida e os funcionários pararem, você não precisará depender de fóruns online para encontrar uma solução. Você tem acesso direto aos nossos experientes engenheiros!",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Você tem um contrato com o fornecedor enviando informações de segurança, atenuações, correções e atualizações antecipadas.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Se você precisar ficar mais tempo na sua versão atual sem interrupções, não precisará rodar o software sem as atualizações de segurança.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Você tem a melhor experiência disponível para lidar com problemas de desempenho e escalabilidade.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Você tem acesso à documentação e experiência corretas para responder rapidamente as questões de conformidade ou cumprir GDPR, HIPAA e outros requisitos de regulamentação.",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication and other features only available in a limited form for free or develop further integrations and capabilities to your needs." : "Também podemos fornecer integração do Outlook, Escritório Online, comunicação de áudio e chat integrado escalável e outros recursos disponíveis apenas de forma limitada ou desenvolver mais integrações e recursos às suas necessidades.",
    "A subscription helps you get the most out of Nextcloud!" : "Uma assinatura ajuda você a aproveitar ao máximo o Nextcloud!",
    "Learn more now" : "Saiba mais agora",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Este e-mail foi enviado a todos os administradores pelo aplicativo de suporte em seu Nextcloud em %1$s porque você tem mais que %2$s usuários registrados.",
    "Your Nextcloud server Subscription is over limit" : "Sua Assinatura do servidor Nextcloud está acima do limite",
    "Dear admin," : "Prezado admin,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "Sua Assinatura Nextcloud não cobre o número de usuários atualmente ativos neste servidor. Entre em contato com seu gerente de conta do Nextcloud para atualizar sua assinatura!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s é o seu gerente de conta e pode ser acessado por e-mail via %2$s ou telefone via %3$s.",
    "Thank you," : "Obrigado,",
    "Your Nextcloud team" : "Sua equipe Nextcloud",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "Este e-mail foi enviado a todos os administradores pelo aplicativo de suporte do Nextcloud em  %s porque você tem mais usuários do que sua assinatura cobre.",
    "Your Nextcloud server Subscription is expired" : "Sua assinatura Nextcloud expirou",
    "Your Nextcloud server Subscription is expired!" : "Sua assinatura Nextcloud expirou!",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "Sua Assinatura Nextcloud expirou! Entre em contato com seu gerente de conta do Nextcloud para atualizá-la!",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Este e-mail foi enviado a todos os administradores pelo aplicativo de suporte em seu Nextcloud em %s porque sua assinatura expirou.",
    "Support" : "Suporte",
    "Getting support and help for your Nextcloud" : "Obtendo suporte e ajuda para o seu Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "O aplicativo de suporte fornece acesso direto a recursos de ajuda e consultoria, contato dedicado com seu gerente de conta e uma visão geral da sua assinatura corporativa.",
    "Basic subscription" : "Assinatura Básica",
    "Standard subscription" : "Assinatura Padrão",
    "Premium subscription" : "Assinatura Premium",
    "Géant subscription" : "Assinatura Gigante",
    "Silver partner subscription" : "Assinatura de parceiro Prata",
    "Gold partner subscription" : "Assinatura de parceiro Ouro",
    "Subscription" : "Assinatura",
    "Over subscription limit" : "Limite da assinatura",
    "Valid subscription" : "Assinatura válida",
    "Expired subscription" : "Assinatura expirada",
    "Subscription key:" : "Chave de assinatura:",
    "Expires in: " : "Expira em:",
    "_%n year_::_%n years_" : ["%n ano","%n anos"],
    "_%n month_::_%n months_" : ["%n mês","%n meses"],
    "_%n week_::_%n weeks_" : ["%n semana","%n semanas"],
    "_%n day_::_%n days_" : ["%n dia","%n dias"],
    "For an unlimited amount of users" : "Para uma quantidade ilimitada de usuários",
    "_For %n active users_::_For %n active users_" : ["Para %n usuário ativo","Para %n usuários ativos"],
    "_For %n users_::_For %n users_" : ["Para %n usuário","Para %n usuários"],
    "_currently at %n user_::_currently at %n users_" : ["atualmente com %n usuário","atualmente com %n usuários"],
    "Includes support for %s" : "Inclui suporte para %s",
    "Includes support for %1$s & %2$s" : "Inclui suporte para %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Inclui suporte para %1$s, %2$s & %3$s",
    "Extended maintenance life cycle" : "Ciclo de vida de manutenção estendida",
    "Update subscription key" : "Atualizar chave de assinatura",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s é o seu gerente de conta. Não hesite em entrar em contato conosco se tiver dúvidas sobre sua assinatura.",
    "You can find answers to common question in our portal and also file support requests there." : "Você pode encontrar respostas para perguntas frequentes em nosso portal e também solicitações de suporte.",
    "Access Nextcloud portal" : "Acessar o portal Nextcloud",
    "System information" : "Informação do sistema",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Obtenha informações do sistema para o suporte. O botão abaixo gera um arquivo de texto na pasta \"Informações do sistema\" e o compartilha como um link público protegido por senha. O link é válido por 2 semanas.",
    "Generate system report" : "Gerar relatório do sistema",
    "Enterprise subscription recommended" : "Assinatura corporativa recomendada",
    "No active enterprise subscription" : "Nenhuma assinatura corporativa ativa",
    "Unsupported" : "Não suportado",
    "This Nextcloud server has no Enterprise Subscription." : "Este servidor não tem uma Assinatura Corporativa.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Uma Assinatura Corporativa tira o máximo do Nextcloud, mantém seus dados seguros e o servidor funcionará de maneira confiável o tempo todo.",
    "Advantages" : "Vantagens",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Acesso ao conhecimento técnico dos desenvolvedores do Nextcloud por meio de documentação e suporte",
    "Access to additional capabilities like Outlook integration, online office and more" : "Acesso a recursos adicionais como integração com o Outlook, office online e muito mais",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Acesso a conhecimento em escalabilidade e capacidades para Arquivos e Conversas",
    "Optional branding, consulting, architecture advice" : "Branding opcional, consultoria e aconselhamento de arquitetura",
    "Confidential security notification service, mitigations, patches and advice" : "Serviço de notificação de segurança confidencial, atenuação de problemas, patches e conselhos",
    "Compliance certification, advice and documentation" : "Certificação de conformidade, aconselhamento e documentação",
    "Get a quote" : "Peça um orçamento",
    "More information" : "Mais informações",
    "Subscription benefits" : "Benefícios da assinatura",
    "Pricing" : "Preço",
    "Community support" : "Apoio da comunidade",
    "Forum" : "Fórum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud é um software livre que é suportado por uma comunidade muito ativa. Por favor, registre-se no fórum para perguntas e conversas com outras pessoas.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "O Nextcloud usa o GitHub como plataforma de trabalho colaborativo. Você pode enviar relatórios de erros diretamente lá.",
    "Chat" : "Bate-papo",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Converse conosco no canal IRC #nextcloud no Freenode.",
    "Nextcloud forum" : "Fórum Nextcloud",
    "Nextcloud at GitHub" : "Nextcloud no GitHub",
    "Open chat" : "Abrir bate-papo",
    "Subscription key" : "Chave de assinatura",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Se você tiver uma Assinatura Nextcloud ativa, insira a chave de assinatura aqui.",
    "Learn more about an enterprise subscription." : "Saiba mais sobre assinatura corporativa.",
    "Set subscription key" : "Definir uma chave de assinatura",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "A informação da assinatura não pôde ser obtida no momento. Uma nova tentativa foi agendada, volte mais tarde.",
    "The subscription key was invalid." : "A chave de assinatura é inválida.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Não foi possível verificar a chave de assinatura porque esse servidor não tem conexão à internet. Entre em contato com a equipe de suporte para resolver isso.",
    "The subscription key had an invalid format." : "A chave de assinatura tem um formato inválido.",
    "While fetching the subscription information an error happened." : "Ocorreu um erro ao buscar as informações da assinatura.",
    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "O botão abaixo gera um arquivo de texto na pasta \"Informações do sistema\" e o compartilha como um link público protegido por senha. O link é válido por duas semanas.",
    "News" : "Notícias",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Para informações atualizadas sobre o Nextcloud, inscreva-se no boletim informativo e siga-nos nas redes sociais.",
    "Like our Facebook page" : "Curta nossa página no Facebook",
    "Follow us on Twitter" : "Siga-nos no Twitter",
    "Check out our blog" : "Verifique nosso blog",
    "Subscribe to our newsletter" : "Assine nosso boletim informativo"
},
"nplurals=2; plural=(n > 1);");
